=================================
The gocept.loginuser distribution
=================================

.. image:: https://travis-ci.com/gocept/gocept.loginuser.svg?branch=master
    :target: https://travis-ci.com/gocept/gocept.loginuser
.. image:: https://coveralls.io/repos/github/gocept/gocept.loginuser/badge.svg
    :target: https://coveralls.io/github/gocept/gocept.loginuser

Sqlalchemy user object and password management.

This package is compatible with Python version 2.7 and 3.5 up to 3.8.
